@@ -859,17 +859,36 @@ def render_dot(dot, output_format="svg"):
     if output_format not in ["svg", "png"]:
         log.error("Invalid output format for render_dot(): {output_format}")
 
-    args = ["dot", f"-T{output_format}"]
+    dot_bin = find_program("dot")
+    if not dot_bin:
+        return None
+
+    args = []
+    args.append(dot_bin)
+    args.append(f"-T{output_format}")
 
     try:
         proc = subprocess.Popen(args, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         proc.stdin.write(dot.encode("utf-8"))
         output, err = proc.communicate()
-        if err:
+        if proc.returncode:
             log.warning(f"Unable to process dot data: {err}")
             return None
         if output_format == "svg":
-            return output.decode("utf-8")
+            svg = output.decode("utf-8")
+            res = []
+            # The SVG generated by dot is meant to be used as a separate file, so
+            # it includes the XML version and DOCTYPE preambles; this generates
+            # invalid HTML when embedded into a web page.
+            for line in svg.split("\n"):
+                if line.startswith("<?xml version"):
+                    continue
+                if line.startswith("<!DOCTYPE svg"):
+                    continue
+                if "svg11.dtd" in line:
+                    continue
+                res.append(line)
+            return "\n".join(res)
     except Exception as e:
         log.warning(f"Unable to process dot data: {e}")
         return None
@@ -878,12 +897,14 @@ def render_dot(dot, output_format="svg"):
 found_programs = {}
 
 
-def find_program(bin_name, path=None):
+def find_program(bin_name, path=None, error_if_not_found=False):
     """Finds a program @bin_name inside the given @path, and returns
     its full path if found, or None if the program could not be found.
 
     The @bin_name will automatically get an extension depending on the
     platform.
+
+    If @error_if_not_found is True, then we'll log an error.
     """
     global found_programs
 
@@ -916,6 +937,9 @@ def find_program(bin_name, path=None):
                     found_programs[bin_name] = full_path
                 return full_path
 
+    if error_if_not_found:
+        log.error(f"Unable to find {bin_name}")
+
     return None
 
 
